@@ -1,7 +1,7 @@
 package File::Write::Rotate;
 
-our $DATE = '2014-12-05'; # DATE
-our $VERSION = '0.25'; # VERSION
+our $DATE = '2015-01-22'; # DATE
+our $VERSION = '0.26'; # VERSION
 
 use 5.010001;
 use strict;
@@ -10,6 +10,7 @@ use warnings;
 # we must not use Log::Any, looping if we are used as log output
 #use Log::Any '$log';
 
+use Carp;
 use File::Spec;
 use IO::Compress::Gzip qw(gzip $GzipError);
 use Scalar::Util qw(weaken);
@@ -22,19 +23,19 @@ sub new {
     my $class = shift;
     my %args  = @_;
 
-    defined( $args{dir} )    or die "Please specify dir";
-    defined( $args{prefix} ) or die "Please specify prefix";
+    defined( $args{dir} )    or croak "Please specify dir";
+    defined( $args{prefix} ) or croak "Please specify prefix";
     $args{suffix} //= "";
 
     $args{size} //= 0;
 
     if ( $args{period} ) {
         $args{period} =~ /daily|day|month|year/i
-          or die "Invalid period, please use daily/monthly/yearly";
+          or croak "Invalid period, please use daily/monthly/yearly";
     }
 
     for (grep {/\Ahook_/} keys %args) {
-        die "Invalid $_, please supply a coderef"
+        croak "Invalid $_, please supply a coderef"
             unless ref($args{$_}) eq 'CODE';
     }
 
@@ -46,7 +47,15 @@ sub new {
 
     $args{_buffer} = [];
 
+    $args{lock_mode} //= 'write';
+    $args{lock_mode} =~ /\A(none|write|exclusive)\z/
+      or croak "Invalid lock_mode, please use none/write/exclusive";
+
     my $self = bless \%args, $class;
+
+    $self->{_exclusive_lock} = $self->_get_lock
+        if $self->{lock_mode} eq 'exclusive';
+
     $self;
 }
 
@@ -120,6 +129,7 @@ sub lock_file_path {
 
 sub _get_lock {
     my ($self) = @_;
+    return undef if $self->{lock_mode} eq 'none';
     return $self->{_weak_lock} if defined($self->{_weak_lock});
 
     require File::Flock::Retry;
@@ -426,7 +436,7 @@ sub DESTROY {
 
 1;
 
-#ABSTRACT: Write to files that archive/rotate themselves
+# ABSTRACT: Write to files that archive/rotate themselves
 
 __END__
 
@@ -440,7 +450,7 @@ File::Write::Rotate - Write to files that archive/rotate themselves
 
 =head1 VERSION
 
-This document describes version 0.25 of File::Write::Rotate (from Perl distribution File-Write-Rotate), released on 2014-12-05.
+This document describes version 0.26 of File::Write::Rotate (from Perl distribution File-Write-Rotate), released on 2015-01-22.
 
 =head1 SYNOPSIS
 
@@ -473,9 +483,9 @@ potentially long time.
 =head1 DESCRIPTION
 
 This module can be used to write to file, usually for logging, that can rotate
-itself. File will be opened in append mode. Locking will be done to avoid
-conflict when there are multiple writers. Rotation can be done by size (after a
-certain size is reached), by time (daily/monthly/yearly), or both.
+itself. File will be opened in append mode. By default, locking will be done to
+avoid conflict when there are multiple writers. Rotation can be done by size
+(after a certain size is reached), by time (daily/monthly/yearly), or both.
 
 I first wrote this module for logging script STDERR output to files (see
 L<Tie::Handle::FileWriteRotate>).
@@ -634,6 +644,17 @@ keep C<.1> file, and so on.
 Set initial value of buffer. See the C<buffer_size> attribute for more
 information.
 
+=item * lock_mode => STR (default: 'write')
+
+Can be set to either C<none>, C<write>, or C<exclusive>. C<none> disables
+locking and increases write performance, but should only be used when there is
+only one writer. C<write> acquires and holds the lock for each write.
+C<exclusive> acquires the lock at object creation and holds it until the the
+object is destroyed.
+
+Lock file is named C<< <prefix> >>C<.lck>. Will wait for up to 1 minute to
+acquire lock, will die if failed to acquire lock.
+
 =item * hook_before_write => CODE
 
 =item * hook_before_rotate => CODE
@@ -655,9 +676,7 @@ on C<dir> and C<prefix> attributes.
 
 Write to file. Will automatically rotate file if period changes or file size
 exceeds specified limit. When rotating, will only keep a specified number of
-histories and delete the older ones. Uses locking, so multiple writers do not
-clobber one another. Lock file is named C<< <prefix> >>C<.lck>. Will wait for up
-to 1 minute to acquire lock, will die if failed to acquire lock.
+histories and delete the older ones.
 
 Does not append newline so you'll have to do it yourself.
 
@@ -679,23 +698,24 @@ again on the next C<write()> if necessary.
 =head2 Why use autorotating file?
 
 Mainly convenience and low maintenance. You no longer need a separate rotator
-like the Unix B<logrotate> utility (which when accidentally disabled or
+process like the Unix B<logrotate> utility (which when accidentally disabled or
 misconfigured will cause your logs to stop being rotated and grow indefinitely).
 
 =head2 What is the downside of using FWR (and LDFR)?
 
-Mainly performance overhead, as every write() involves locking to make it safe
-to use with multiple processes. Tested on my Core i5 3.1 GHz desktop, writing
-lines in the size of ~ 200 bytes, raw writing to disk (SSD) has the speed of
-around 3.4mil/s, while using FWR it comes down to around 19.5k/s.
+Mainly (significant) performance overhead. At (almost) every C<write()>, FWR
+needs to check file sizes and dates for rotation. Under default configuration
+(where C<lock_mode> is C<write>), it also performs locking on each C<write()> to
+make it safe to use with multiple processes. Below is a casual benchmark to give
+a sense of the overhead, tested on my Core i5-2400 3.1GHz desktop:
+
+Writing lines in the size of ~ 200 bytes, raw writing to disk (SSD) has the
+speed of around 3.4mil/s, while using FWR it goes down to around ~13k/s. Using
+C<lock_mode> C<none> or C<exclusive>, the speed is ~52k/s.
 
 However, this is not something you'll notice or need to worry about unless
 you're writing near that speed.
 
-=head1 TODO
-
-Perhaps an option to disable locking.
-
 =head1 SEE ALSO
 
 L<Log::Dispatch::FileRotate>, which inspires this module. Differences between
@@ -756,7 +776,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
